@@ -1,108 +1,158 @@
 package Validator::Custom;
-use base 'Object::Simple';
 
 use strict;
 use warnings;
+
+use base 'Object::Simple';
+
 use Carp 'croak';
-
 use Validator::Custom::Result;
 
-__PACKAGE__->attr('validation_rule');
-__PACKAGE__->attr(error_stock => 1);
-
 __PACKAGE__->dual_attr('constraints', default => sub { {} },
                                       inherit => 'hash_copy');
+__PACKAGE__->attr(error_stock => 1);
+__PACKAGE__->attr('rule');
+__PACKAGE__->attr(syntax => <<'EOS');
+### Syntax of validation rule
+    my $rule = [                          # 1. Rule is array ref
+        key1 => [                         # 2. Constraints is array ref
+            'constraint1_1',              # 3. Constraint is string
+            ['constraint1_2', 'error1_2'],#      or arrya ref (error message)
+            {'constraint1_3' => 'string'} #      or hash ref (arguments)
+              
+        ],
+        key2 => [
+            {'constraint2_1'              # 4. Argument is string
+              => 'string'},               #
+            {'constraint2_2'              #     or array ref
+              => ['arg1', 'arg2']},       #
+            {'constraint1_3'              #     or hash ref
+              => {k1 => 'v1', k2 => 'v2'}}#
+        ],
+        key3 => [                           
+            [{constraint3_1 => 'string'}, # 5. Combination argument
+             'error3_1' ]                 #     and error message
+        ],
+        { key4 => ['key4_1', 'key4_2'] }  # 6. Multi key validation
+            => [
+                'constraint4_1'
+               ],
+        key5 => [
+            '@constraint5_1'              # 7. array's items validation
+        ]
+    ];
+
+EOS
+__PACKAGE__->attr('validation_rule'); # Deprecated
 
-# Add constraint function
 sub add_constraint {
     my $invocant = shift;
     
+    # Merge
     my $constraints = ref $_[0] eq 'HASH' ? $_[0] : {@_};
     $invocant->constraints({%{$invocant->constraints}, %$constraints});
     
     return $invocant;
 }
 
-# Validate
 sub validate {
-    my ($self, $data, $validation_rule) = @_;
+    my ($self, $data, $rule) = @_;
+    
+    # Class
     my $class = ref $self;
     
     # Validation rule
-    $validation_rule ||= $self->validation_rule;
+    $rule ||= $self->rule || $self->validation_rule;
     
-    # Data must be hash ref
+    # Check data
     croak "Data which passed to validate method must be hash ref"
       unless ref $data eq 'HASH';
     
-    # Validation rule must be array ref
+    # Check rule
     croak "Validation rule must be array ref\n" .
           "(see syntax of validation rule 1)\n" .
-          $self->_validation_rule_usage($validation_rule)
-      unless ref $validation_rule eq 'ARRAY';
+          $self->_rule_syntax($rule)
+      unless ref $rule eq 'ARRAY';
     
-    # Result object
+    # Result
     my $result = Validator::Custom::Result->new;
     
     # Error is stock?
     my $error_stock = $self->error_stock;
     
     # Process each key
-    VALIDATOR_LOOP:
-    for (my $i = 0; $i < @{$validation_rule}; $i += 2) {
-        my ($key, $constraints) = @{$validation_rule}[$i, ($i + 1)];
+    OUTER_LOOP:
+    for (my $i = 0; $i < @{$rule}; $i += 2) {
         
+        # Key and constraints
+        my ($key, $constraints) = @{$rule}[$i, ($i + 1)];
+        
+        # Check constraints
         croak "Constraints of validation rule must be array ref\n" .
               "(see syntax of validation rule 2)\n" .
-              $self->_validation_rule_usage($validation_rule)
+              $self->_rule_syntax($rule)
           unless ref $constraints eq 'ARRAY';
         
-        # Rearrange key
+        # Arrange key
         my $product_key = $key;
-        
         if (ref $key eq 'HASH') {
             my $first_key = (keys %$key)[0];
-            ($product_key, $key) = ($first_key, $key->{$first_key});
+            $product_key = $first_key;
+            $key         = $key->{$first_key};
         }
         elsif (ref $key eq 'ARRAY') {
             $product_key = "$key";
         }
         
+        # Validation
         my $value;
         my $products;
         foreach my $constraint (@$constraints) {
             
-            # Rearrange validator information
-            my ($constraint, $error_message)
+            # Arrange constraint information
+            my ($constraint, $message)
               = ref $constraint eq 'ARRAY' ? @$constraint : ($constraint);
             
+            # Data type
             my $data_type = {};
+            
+            # Arguments
             my $arg;
             
+            # Arrange constraint
             if(ref $constraint eq 'HASH') {
                 my $first_key = (keys %$constraint)[0];
-                ($constraint, $arg) = ($first_key, $constraint->{$first_key});
+                $arg        = $constraint->{$first_key};
+                $constraint = $first_key;
             }
             
+            # Constraint function
             my $constraint_function;
-            # Expression is code reference
+            
+            # Sub reference
             if( ref $constraint eq 'CODE') {
+                
+                # Constraint function
                 $constraint_function = $constraint;
             }
             
-            # Expression is string
+            # Constraint key
             else {
+                
+                # Array constraint
                 if($constraint =~ /^\@(.+)$/) {
                     $data_type->{array} = 1;
                     $constraint = $1;
                 }
                 
+                # Check constraint key
                 croak "Constraint type '$constraint' must be [A-Za-z0-9_]"
                   if $constraint =~ /\W/;
                 
-                # Get validator function
+                # Constraint function
                 $constraint_function = $self->constraints->{$constraint};
                 
+                # Check constraint function
                 croak "'$constraint' is not resisted"
                   unless ref $constraint_function eq 'CODE'
             }
@@ -111,17 +161,22 @@ sub validate {
             my $is_valid;
             if($data_type->{array}) {
                 
-                $value = ref $data->{$key} eq 'ARRAY' ? $data->{$key} : [$data->{$key}]
-                  unless defined $value;
+                unless (defined $value) {
+                    $value = ref $data->{$key} eq 'ARRAY' 
+                           ? $data->{$key}
+                           : [$data->{$key}]
+                }
                 
                 my $first_validation = 1;
                 foreach my $data (@$value) {
                     my $product;
                     eval {
-                        ($is_valid, $product) = $constraint_function->($data, $arg, $self);
+                        ($is_valid, $product)
+                          = $constraint_function->($data, $arg, $self);
                     };
                     
-                    croak "Constraint exception(Key '$product_key'). Error message: $@\n"
+                    croak "Constraint exception(Key '$product_key')." .
+                          " Error message: $@\n"
                       if $@;
                     
                     last unless $is_valid;
@@ -137,14 +192,19 @@ sub validate {
                 $value = $products if defined $products;
             }
             else {
-                $value = ref $key eq 'ARRAY' ? [map { $data->{$_} } @$key] : $data->{$key}
-                  unless defined $value;
+                unless (defined $value) {
+                    $value = ref $key eq 'ARRAY'
+                           ? [map { $data->{$_} } @$key]
+                           : $data->{$key}
+                }
                 
                 eval {
-                    ($is_valid, $products) = $constraint_function->($value, $arg, $self);
+                    ($is_valid, $products)
+                      = $constraint_function->($value, $arg, $self);
                 };
                 
-                croak "Constraint exception(Key '$product_key'). Error message: $@\n"
+                croak "Constraint exception(Key '$product_key'). " .
+                      "Error message: $@\n"
                   if $@;
                 
                 $value = $products if $is_valid && defined $products;
@@ -155,11 +215,11 @@ sub validate {
                 $products = undef;
                 
                 # Resist error info
-                push @{$result->_errors},
-                     {invalid_key => $product_key, message => $error_message};
+                $result->add_error_info({invalid_key => $product_key,
+                                         message     => $message});
                 
-                last VALIDATOR_LOOP unless $error_stock;
-                next VALIDATOR_LOOP;
+                last OUTER_LOOP unless $error_stock;
+                next OUTER_LOOP;
             }
         }
         $result->products->{$product_key} = $products if defined $products;
@@ -167,47 +227,14 @@ sub validate {
     return $result;
 }
 
-sub syntax {return <<'EOS' }
-### Syntax of validation rule         
-my $validation_rule = [               # 1.Validation rule must be array ref
-    key1 => [                         # 2.Constraints must be array ref
-        'constraint1_1',              # 3.Constraint can be string
-        ['constraint1_2', 'error1_2'],#     or arrya ref (error message)
-        {'constraint1_3' => 'string'} #     or hash ref (arguments)
-          
-    ],
-    key2 => [
-        {'constraint2_1'              # 4.Argument can be string
-          => 'string'},               #
-        {'constraint2_2'              #     or array ref
-          => ['arg1', 'arg2']},       #
-        {'constraint1_3'              #     or hash ref
-          => {k1 => 'v1', k2 => 'v2}} #
-    ],
-    key3 => [                           
-        [{constraint3_1' => 'string'},# 5.Combination argument
-         'error3_1' ]                 #     and error message
-    ],
-    { key4 => ['key4_1', 'key4_2'] }  # 6.Multi key validation
-        => [
-            'constraint4_1'
-           ]
-    key5 => [
-        '@constraint5_1'              # 7.Array each value validation
-    ]
-];
-
-EOS
-
-# Validation rule usage
-sub _validation_rule_usage {
-    my ($self, $validation_rule) = @_;
+sub _rule_syntax {
+    my ($self, $rule) = @_;
     
     my $message = $self->syntax;
     
     require Data::Dumper;
     $message .= "### Your validation rule:\n";
-    $message .= Data::Dumper->Dump([$validation_rule], ['$validation_rule']);
+    $message .= Data::Dumper->Dump([$rule], ['$rule']);
     $message .= "\n";
     return $message;
 }
@@ -218,21 +245,20 @@ Validator::Custom - Custom validator
 
 =head1 VERSION
 
-Version 0.0708
+Version 0.0801
 
 =cut
 
-our $VERSION = '0.0708';
+our $VERSION = '0.0801';
 
 =head1 SYNOPSYS
     
-    ### How to use Validator::Custom
+    use Validator::Custom;
+
+    # New
+    my $vc = Validator::Custom->new;
     
-    
-    # Validate
-    my $vc = Validator::Custom->new
-    
-    # Constraint
+    # Add Constraint
     $vc->add_constraint(
         int => sub {
             my $value    = shift;
@@ -248,40 +274,42 @@ our $VERSION = '0.0708';
             my $value = shift;
             my $is_valid = $value ne '';
             return $is_valid;
-        }
+        },
         length => sub {
             my ($value, $args) = @_;
             my ($min, $max) = @$args;
-            my $is_valid = $min <= $length && $length <= $max;
+            my $length = length $value;
+            my $is_valid = $length >= $min && $length <= $max;
             return $is_valid;
         }
     );
     
     # Data
-    my $data = { age => 19, names => ['abc', 'def'] };
+    my $data = { 
+        age => 19, 
+        names => ['abcoooo', 'def']
+    };
     
     # Validation rule
-    $vc->validation_rule([
+    $vc->rule([
         age => [
             'int'
         ],
-        '@names' => [
-            ['not_blank',          "name must exist"],
-            ['ascii',              "name must be ascii"],
-            [{'length' => [1, 5]}, "name must be 1 to 5"]
+        names => [
+            ['@not_blank',          "name must exist"],
+            ['@ascii',              "name must be ascii"],
+            [{'@length' => [1, 5]}, "name must be 1 to 5"]
         ]
     ]);
     
     # Validation
-    my $result = $vc->validate($data, $validation_rule);
+    my $result = $vc->validate($data);
     
-    # Get errors
+    # Get all error messages
     my @errors = $result->errors;
     
-    # Handle errors
-    foreach my $error (@errors) {
-        # ...
-    }
+    # Get a error message
+    my $error = $result->error('age');
     
     # Get invalid keys
     my @invalid_keys = $result->invalid_keys;
@@ -289,137 +317,112 @@ our $VERSION = '0.0708';
     # Get producted value
     my $products = $result->products;
     
-    # Check valid or not
-    if($result->is_valid) {
-        # ...
-    }
+    # Is all data valid?
+    my $ret = $result->is_valid;
+    
+    # Is a data valid
+    $ret = $result->is_valid('age');
     
     # Corelative check
-    my $validation_rule => [
-        [qw/password1 password2/] => [
-            ['duplicate', 'Passwor is not same']
-        ]
-    ]
-    
-    # Specify key
-    my $validation_rule => [
+    my $rule = [
         {password_check => [qw/password1 password2/]} => [
             ['duplicate', 'Passwor is not same']
         ]
-    ]
-    
-=head1 Accessors
+    ];
+        
+=head1 ATTRIBUTES
 
 =head2 constraints
 
-get constraints
-    
-Set and get constraint functions
+Constraint functions
 
-    $vc          = $vc->constraints($constraints); # hash or hash ref
+    $vc          = $vc->constraints($constraints);
     $constraints = $vc->constraints;
 
-constraints sample
+Sample
 
     $vc->constraints(
         int    => sub { ... },
         string => sub { ... }
     );
-
-See also 'add_constraint' method
-
+    
 =head2 error_stock
 
-Set and get whether error is stocked or not.
+Are errors stocked?
 
-    $vc          = $vc->error_stock(1);
+    $vc          = $vc->error_stock(0);
     $error_stock = $vc->error_stcok;
     
-If you set stock_error 1, occured error on validation is stocked,
-and you can get all errors by errors mehtods.
+If you set 0, validation errors is not stocked.
+Validation is finished when one error is occured.
+This is faster than stocking all errors.
 
-If you set stock_error 0, you can get only first error by errors method.
+Default is 1. All errors are stocked.
 
-This is very high performance if you know only whether error occur or not.
+=head2 rule
 
-    $vc->stock_error(0);
-    $is_valid = $vc->validate($data, $validation_rule)->is_valid;
+Validation rule
 
-error_stock default is 1. 
+    $vc   = $vc->rule($rule);
+    $rule = $vc->rule;
 
-=head2 validation_rule
-
-Set and get validation rule
-
-    $vc              = $vc->validation_rule($validation_rule);
-    $validation_rule = $vc->validation_rule;
-
-Validation rule has the following syntax
+Validation rule has the following syntax.
 
     ### Syntax of validation rule         
-    my $validation_rule = [               # 1.Validation rule must be array ref
-        key1 => [                         # 2.Constraints must be array ref
-            'constraint1_1',              # 3.Constraint can be string
-            ['constraint1_2', 'error1_2'],#     or arrya ref (error message)
-            {'constraint1_3' => 'string'} #     or hash ref (arguments)
+    my $rule = [                          # 1. Validation rule is array ref
+        key1 => [                         # 2. Constraints is array ref
+            'constraint1_1',              # 3. Constraint is string
+            ['constraint1_2', 'error1_2'],#      or arrya ref (error message)
+            {'constraint1_3' => 'string'} #      or hash ref (arguments)
               
         ],
         key2 => [
-            {'constraint2_1'              # 4.Argument can be string
+            {'constraint2_1'              # 4. Argument is string
               => 'string'},               #
             {'constraint2_2'              #     or array ref
               => ['arg1', 'arg2']},       #
             {'constraint1_3'              #     or hash ref
-              => {k1 => 'v1', k2 => 'v2}} #
+              => {k1 => 'v1', k2 => 'v2'}}#
         ],
         key3 => [                           
-            [{constraint3_1' => 'string'},# 5.Combination argument
+            [{constraint3_1 => 'string'}, # 5. Combination argument
              'error3_1' ]                 #     and error message
         ],
-        { key4 => ['key4_1', 'key4_2'] }  # 6.Multi key validation
+        { key4 => ['key4_1', 'key4_2'] }  # 6. Multi key validation
             => [
                 'constraint4_1'
-               ]
+               ],
         key5 => [
-            '@constraint5_1'              # 7. array ref each value validation
+            '@constraint5_1'              # 7. array's items validation
         ]
     ];
-    
-You can see this syntax using 'syntax' method
 
-    print $vc->syntax;
+("validation_rule" is deprecated. It is renamed to "rule")
 
-=head1 Mehtods
+=head2 syntax
+
+Syntax of validation rule
+
+    $vc     = $vc->syntax($syntax);
+    $syntax = $vc->syntax;
+
+=head1 MEHTODS
 
 =head2 new
 
-Create object
+Constructor
 
     $vc = Validator::Costom->new;
-
-=head2 validate
-
-validate data
-
-    # Validation
-    $result = $vc->validate($data, $validation_rule);
-    $result = $vc->validate($data);
-
-If you omit $validation_rule, $vc->validation_rule is used.
-
-See 'validation_rule' description about validation rule.
-
-This method return L<Validator::Custom::Result> object,
-
-See also L<Validator::Custom::Result>.
+    $vc = Validator::Costom->new(rule => [ .. ]);
 
 =head2 add_constraint
 
-Add constraint
+Add constraint function
 
-    $vc->add_constraint($constraint); # hash or hash ref
-
-'add_constraint' sample
+    $vc->add_constraint(%constraint);
+    $vc->add_constraint(\%constraint);
+    
+Sample
     
     $vc->add_constraint(
         int => sub {
@@ -434,12 +437,15 @@ Add constraint
         }
     );
 
-=head2 syntax
+=head2 validate
 
-Set and get syntax of validation rule
+Validation
 
-    $vc     = $vc->syntax($syntax);
-    $syntax = $vc->syntax;
+    $result = $vc->validate($data, $rule);
+    $result = $vc->validate($data);
+
+If you omit $rule, $vc->rule is used.
+Return value is L<Validator::Custom::Result> object.
 
 =head1 Validator::Custom::Result
 
@@ -450,7 +456,7 @@ See L<Validator::Custom::Result>.
 The following is L<Validator::Custom::Result> sample
 
     # Restlt
-    $result = $vc->validate($data, $validation_rule);
+    $result = $vc->validate($data, $rule);
     
     # Error message
     @errors = $result->errors;
@@ -465,7 +471,7 @@ The following is L<Validator::Custom::Result> sample
     # Is it valid?
     $is_valid = $result->is_valid;
 
-=head1 Constraint function
+=head1 CONSTRAINT FUNCTION
 
 You can resist your constraint function using 'add_constraint' method.
 
@@ -478,7 +484,7 @@ I explain using sample. You can pass argument in validation rule.
 and you can receive the argument in constraint function
 
     my $data = {key => 'value'}; # 1. value
-    my $validation_rule => {
+    my $rule => {
         key => [
             {'name' => $args} # 2. arguments
         ],
@@ -502,9 +508,9 @@ constraint function also can return producted value.
         return ($is_valid, $product);
     });
 
-L<Validator::Custom::HTML::Form> 'time' constraint function is good sample.
+L<Validator::Custom::HTML::Form> is good sample.
 
-=head1 Create custom class extending Validator::Custom 
+=head1 CUSTOM CLASS
 
 You can create your custom class extending Validator::Custom.
 
@@ -530,17 +536,13 @@ This class is avalilable same way as Validator::Custom
 
 L<Validator::Custom::Trim>, L<Validator::Custom::HTMLForm> is good sample.
 
-=head1 Author
+=head1 AUTHOR
 
 Yuki Kimoto, C<< <kimoto.yuki at gmail.com> >>
 
-Github L<http://github.com/yuki-kimoto>
+Development L<http://github.com/yuki-kimoto/Validator-Custom>
 
-I develope this module at L<http://github.com/yuki-kimoto/Validator-Custom>
-
-I also support at IRC irc.perl.org#validator-custom
-
-=head1 Copyright & licence
+=head1 COPYRIGHT & LICENCE
 
 Copyright 2009 Yuki Kimoto, all rights reserved.
 
